@@ -7,4 +7,5 @@ from __future__ import absolute_import
 from .version import __version_info__, __version__
 
 # Export public objects
-from .tdms import TdmsFile, TdmsObject
+from .tdms import TdmsFile, TdmsGroup, TdmsChannel
+from .writer import TdmsWriter, RootObject, GroupObject, ChannelObject
